%define api	0.22
%define major	0
%define libname	%mklibname %{name} %{api} %{major}
%define devname %mklibname -d %{name}

%define url_ver	%(echo %{version}|cut -d. -f1,2)

Summary:	Compiler for the GObject type system
Name:		vala
Version:	0.22.1
Release:	%mkrel 1
Source0:	https://download.gnome.org/sources/%{name}/%{url_ver}/%{name}-%{version}.tar.xz
# Most files are LGPLv2.1+, curses.vapi is 2-clause BSD
License:	LGPLv2+ and BSD
Group:		Development/Other
Url:		https://wiki.gnome.org/Vala
BuildRequires:	pkgconfig(glib-2.0) >= 2.16.0
BuildRequires:	pkgconfig(gmodule-2.0) >= 2.16.0
BuildRequires:	pkgconfig(gobject-2.0) >= 2.16.0
BuildRequires:	pkgconfig(gthread-2.0) >= 2.16.0
BuildRequires:	xsltproc
BuildRequires:	flex
BuildRequires:	bison
Requires:	glib2-devel

%description
Vala is a new programming language that aims to bring modern
programming language features to GNOME developers without imposing any
additional runtime requirements and without using a different ABI
compared to applications and libraries written in C.

valac, the Vala compiler, is a self-hosting compiler that translates
Vala source code into C source and header files. It uses the GObject
type system to create classes and interfaces declared in the Vala
source code. It's also planned to generate GIDL files when
gobject-introspection is ready.

The syntax of Vala is similar to C#, modified to better fit the GObject
type system. Vala supports modern language features as the following:

* Interfaces
* Properties
* Signals
* Foreach
* Lambda expressions
* Type inference for local variables
* Non-null types [PARTIAL]
* Exception handling [PLANNED]
* Assisted memory management

* type modules (aka. Plugins)

Vala is designed to allow access to existing C libraries, especially
GObject-based libraries, without the need for runtime bindings. Each
to be used library requires a Vala API file at compile-time,
containing the class and method declarations in Vala syntax. Vala
currently comes with experimental bindings for GLib and GTK+. It's
planned to provide generated bindings for the full GNOME Platform at a
later stage.

Using classes and methods written in Vala from an application written
in C is not difficult. The Vala library only has to install the
generated header files and C applications may then access the
GObject-based API of the Vala library as usual. It should also be
easily possible to write a bindings generator for access to Vala
libraries from applications written in e.g. C# as the Vala parser is written
as a library, so that all compile-time information is available when
generating a binding.

%package -n %{libname}
Group:		System/Libraries
Summary:	Vala runtime library

%description -n %{libname}
This is the runtime library of the Vala programming language.

%package -n %{devname}
Group:		Development/Other
Summary:	Vala development files
Requires:	%{libname} = %{version}-%{release}
Requires:	%{name} = %{version}-%{release}
Requires:	%{name}-tools = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{devname}
This is the development library of the Vala programming language.

%package tools
Summary:	Tools for creating projects and bindings for %{name}
Group:		Development/Other
Requires:	%{name} = %{version}-%{release}
Requires:	gnome-common
Requires:	intltool
Requires:	libtool

%description tools
This package contains tools to generate Vala projects, as well as API bindings
from existing C libraries, allowing access from Vala programs.

%prep
%setup -q
%apply_patches

%build
autoreconf -vfi
%configure2_5x
%make

%install
%makeinstall_std

find %{buildroot} -name "*.la" -delete

mkdir -p %{buildroot}%{_datadir}/vala/vapi

%files -n %{libname}
%_libdir/libvala-%{api}.so.%{major}*

%files -n %{devname}
%doc ChangeLog
%{_libdir}/libvala-%{api}.so
%{_includedir}/vala-%{api}
%{_libdir}/pkgconfig/*.pc
%{_datadir}/pkgconfig/*.pc
%{_datadir}/devhelp/books/vala-%{api}
%{_datadir}/aclocal/*.m4

%files
%doc AUTHORS MAINTAINERS NEWS README
%{_bindir}/vala
%{_bindir}/vala-%{api}
%{_bindir}/valac
%{_bindir}/valac-%{api}
%{_datadir}/vala-%{api}
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_mandir}/man1/valac.1*
%{_mandir}/man1/valac-%{api}.1*

%files tools
%{_bindir}/*gen*
%{_bindir}/vapicheck
%{_bindir}/vapicheck-%{api}
%{_datadir}/vala/Makefile.vapigen
%{_libdir}/vala-%{api}
%{_mandir}/*/*gen*


%changelog
* Wed Nov 20 2013 ovitters <ovitters> 0.22.1-1.mga4
+ Revision: 551975
- new version 0.22.1

* Sat Nov 09 2013 ovitters <ovitters> 0.22.0-3.mga4
+ Revision: 550203
- fix url

* Sat Oct 19 2013 umeabot <umeabot> 0.22.0-2.mga4
+ Revision: 536499
- Mageia 4 Mass Rebuild

* Mon Sep 23 2013 ovitters <ovitters> 0.22.0-1.mga4
+ Revision: 484415
- new version 0.22.0

* Fri Sep 13 2013 ovitters <ovitters> 0.21.2-1.mga4
+ Revision: 478309
- new version 0.21.2

* Sun Aug 04 2013 wally <wally> 0.21.1-1.mga4
+ Revision: 463197
- new version 0.21.1

* Sat Jul 27 2013 wally <wally> 0.20.1-2.mga4
+ Revision: 458781
- make devel pkg require vala-tools
- drop old obsoletes

* Fri May 24 2013 tv <tv> 0.20.1-1.mga4
+ Revision: 426489
- new release

* Mon Jan 14 2013 umeabot <umeabot> 0.18.1-2.mga3
+ Revision: 385223
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Nov 15 2012 fwang <fwang> 0.18.1-1.mga3
+ Revision: 318000
- new version 0.18.1

* Mon Sep 24 2012 ovitters <ovitters> 0.18.0-1.mga3
+ Revision: 297217
- new version 0.18.0

* Sun Sep 16 2012 mitya <mitya> 0.17.7-1.mga3
+ Revision: 294640
- New version 0.17.7

* Mon Sep 03 2012 ovitters <ovitters> 0.17.6-1.mga3
+ Revision: 287687
- new version 0.17.6

* Mon Aug 20 2012 ovitters <ovitters> 0.17.5-1.mga3
+ Revision: 282599
- drop merged patches
- new version 0.17.5

* Fri Aug 10 2012 wally <wally> 0.17.4-2.mga3
+ Revision: 280436
- add patches from upstream GIT to fix deja-dup build

* Mon Aug 06 2012 ovitters <ovitters> 0.17.4-1.mga3
+ Revision: 279394
- new version 0.17.4

* Mon Jul 16 2012 ovitters <ovitters> 0.17.3-1.mga3
+ Revision: 271521
- new version 0.17.3

* Tue Jun 26 2012 ovitters <ovitters> 0.17.2-1.mga3
+ Revision: 264124
- update api
- new version 0.17.2

* Sat Jun 23 2012 ovitters <ovitters> 0.16.1-1.mga3
+ Revision: 262794
- new version 0.16.1

* Mon Mar 26 2012 ovitters <ovitters> 0.16.0-1.mga2
+ Revision: 226772
- new version 0.16.0

* Sat Feb 25 2012 ovitters <ovitters> 0.15.2-1.mga2
+ Revision: 214753
- new version
- fix source URL

* Sat Jan 28 2012 fwang <fwang> 0.15.1-1.mga2
+ Revision: 202405
- update file list
- update file list
- new version 0.15.1

  + wally <wally>
    - clean .spec

* Thu Dec 01 2011 fwang <fwang> 0.14.1-1.mga2
+ Revision: 174702
- new version 0.14.1

* Mon Oct 03 2011 fwang <fwang> 0.14.0-2.mga2
+ Revision: 151129
- rebuild

* Sun Sep 18 2011 fwang <fwang> 0.14.0-1.mga2
+ Revision: 144777
- new version 0.14.0

* Sat Sep 10 2011 fwang <fwang> 0.13.4-1.mga2
+ Revision: 141988
- new version 0.13.4
- new version 0.13.3
- new version 0.13.2

  + colin <colin>
    - Upstream fix: linux: fix Linux.CLOCK_MONOTONIC_RAW binding

* Sun Jul 10 2011 fwang <fwang> 0.13.1-1.mga2
+ Revision: 121600
- new version 0.13.1

* Tue Jul 05 2011 ahmad <ahmad> 0.13.0-1.mga2
+ Revision: 118631
- Update to 0.13.0
- Drop patch0, now that we have libnotify0.7 in Cauldron

* Mon May 02 2011 pterjan <pterjan> 0.12.0-2.mga1
+ Revision: 94319
- Fix vapi file to describe our version of libnotify

* Tue Apr 05 2011 dams <dams> 0.12.0-1.mga1
+ Revision: 80690
- update to 0.12.0

* Sun Feb 13 2011 spuhler <spuhler> 0.10.3-1.mga1
+ Revision: 51178
- update from version 0.10.2 to version 0.10.3

* Mon Jan 17 2011 blino <blino> 0.10.2-2.mga1
+ Revision: 21502
- remove old ldconfig scriptlets
- imported package vala


* Wed Dec 29 2010 Götz Waschk <waschk@mandriva.org> 0.10.2-1mdv2011.0
+ Revision: 625978
- update to new version 0.10.2
- own vala/vapi dir

* Tue Oct 26 2010 Götz Waschk <waschk@mandriva.org> 0.10.1-1mdv2011.0
+ Revision: 589528
- update to new version 0.10.1

* Sat Sep 18 2010 Götz Waschk <waschk@mandriva.org> 0.10.0-1mdv2011.0
+ Revision: 579347
- update to new version 0.10.0

* Sat Sep 04 2010 Götz Waschk <waschk@mandriva.org> 0.9.8-1mdv2011.0
+ Revision: 575949
- update to new version 0.9.8

* Thu Aug 19 2010 Götz Waschk <waschk@mandriva.org> 0.9.7-1mdv2011.0
+ Revision: 571314
- update to new version 0.9.7

* Wed Aug 18 2010 Götz Waschk <waschk@mandriva.org> 0.9.6-1mdv2011.0
+ Revision: 571173
- update to new version 0.9.6

* Mon Aug 09 2010 Götz Waschk <waschk@mandriva.org> 0.9.5-1mdv2011.0
+ Revision: 567977
- new version
- update file list

* Thu Jul 29 2010 Götz Waschk <waschk@mandriva.org> 0.9.4-1mdv2011.0
+ Revision: 563082
- new version
- drop patch
- bump glib dep
- add %%_bindir/vala

* Wed Apr 21 2010 Götz Waschk <waschk@mandriva.org> 0.8.1-1mdv2010.1
+ Revision: 537648
- update to new version 0.8.1

* Wed Mar 31 2010 Götz Waschk <waschk@mandriva.org> 0.8.0-1mdv2010.1
+ Revision: 530533
- update to new version 0.8.0

* Thu Feb 04 2010 Götz Waschk <waschk@mandriva.org> 0.7.10-1mdv2010.1
+ Revision: 500996
- update to new version 0.7.10

* Sat Dec 19 2009 Götz Waschk <waschk@mandriva.org> 0.7.9-1mdv2010.1
+ Revision: 480162
- update to new version 0.7.9

* Fri Nov 06 2009 Götz Waschk <waschk@mandriva.org> 0.7.8-1mdv2010.1
+ Revision: 460747
- update to new version 0.7.8

* Sat Oct 03 2009 Colin Guthrie <cguthrie@mandriva.org> 0.7.7-2mdv2010.0
+ Revision: 453252
- Fix format-security issues.
- Enable vapigen and package in vala-tools (as per Fedora)

* Sun Sep 27 2009 Götz Waschk <waschk@mandriva.org> 0.7.7-1mdv2010.0
+ Revision: 450206
- update to new version 0.7.7

* Fri Sep 18 2009 Götz Waschk <waschk@mandriva.org> 0.7.6-1mdv2010.0
+ Revision: 444249
- update to new version 0.7.6

* Sun Aug 02 2009 Götz Waschk <waschk@mandriva.org> 0.7.5-1mdv2010.0
+ Revision: 407607
- update to new version 0.7.5

* Sun Jun 28 2009 Götz Waschk <waschk@mandriva.org> 0.7.4-1mdv2010.0
+ Revision: 390425
- update to new version 0.7.4

* Wed May 27 2009 Götz Waschk <waschk@mandriva.org> 0.7.3-1mdv2010.0
+ Revision: 380096
- update build deps
- update to new version 0.7.3

  + Frederic Crozat <fcrozat@mandriva.com>
    - Add dependency on glib2-devel (Mdv bug #50894)
    - Enable checks

* Mon May 11 2009 Götz Waschk <waschk@mandriva.org> 0.7.2-1mdv2010.0
+ Revision: 374162
- new version

* Tue Apr 14 2009 Götz Waschk <waschk@mandriva.org> 0.6.1-1mdv2009.1
+ Revision: 366976
- update to new version 0.6.1

* Tue Mar 31 2009 Götz Waschk <waschk@mandriva.org> 0.6.0-1mdv2009.1
+ Revision: 362800
- new version

* Sat Feb 21 2009 Götz Waschk <waschk@mandriva.org> 0.5.7-1mdv2009.1
+ Revision: 343552
- update to new version 0.5.7

* Sun Jan 18 2009 Götz Waschk <waschk@mandriva.org> 0.5.6-1mdv2009.1
+ Revision: 330983
- update to new version 0.5.6

* Sat Jan 10 2009 Götz Waschk <waschk@mandriva.org> 0.5.5-1mdv2009.1
+ Revision: 328029
- update to new version 0.5.5

* Thu Jan 08 2009 Götz Waschk <waschk@mandriva.org> 0.5.4-1mdv2009.1
+ Revision: 327027
- new version
- drop patch

* Fri Dec 19 2008 Götz Waschk <waschk@mandriva.org> 0.5.3-1mdv2009.1
+ Revision: 316084
- new version
- fix format strings

* Tue Dec 02 2008 Götz Waschk <waschk@mandriva.org> 0.5.2-1mdv2009.1
+ Revision: 309149
- disable checks
- fix checks
- update to new version 0.5.2

* Tue Nov 04 2008 Funda Wang <fwang@mandriva.org> 0.5.1-1mdv2009.1
+ Revision: 299670
- New version 0.5.1

* Tue Oct 21 2008 Götz Waschk <waschk@mandriva.org> 0.4.0-1mdv2009.1
+ Revision: 295930
- new version
- fix source URL

* Thu Aug 14 2008 Götz Waschk <waschk@mandriva.org> 0.3.5-1mdv2009.0
+ Revision: 272193
- new version

* Thu Jul 03 2008 Götz Waschk <waschk@mandriva.org> 0.3.4-1mdv2009.0
+ Revision: 230993
- new version
- update license

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Tue Apr 15 2008 Götz Waschk <waschk@mandriva.org> 0.2.0-1mdv2009.0
+ Revision: 193793
- new version

* Mon Mar 03 2008 Götz Waschk <waschk@mandriva.org> 0.1.7-1mdv2008.1
+ Revision: 177871
- new version

* Sun Jan 20 2008 Götz Waschk <waschk@mandriva.org> 0.1.6-1mdv2008.1
+ Revision: 155296
- new version

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sun Nov 25 2007 Götz Waschk <waschk@mandriva.org> 0.1.5-1mdv2008.1
+ Revision: 111946
- new version

* Tue Oct 09 2007 Götz Waschk <waschk@mandriva.org> 0.1.4-1mdv2008.1
+ Revision: 96572
- new version
- update file list

* Fri Aug 31 2007 Götz Waschk <waschk@mandriva.org> 0.1.3-1mdv2008.0
+ Revision: 76885
- new version

* Sat Jul 28 2007 Götz Waschk <waschk@mandriva.org> 0.1.2-1mdv2008.0
+ Revision: 56459
- new version
- new devel name

* Fri Jul 13 2007 Götz Waschk <waschk@mandriva.org> 0.1.1-1mdv2008.0
+ Revision: 51810
- new version

* Mon Jul 09 2007 Götz Waschk <waschk@mandriva.org> 0.1.0-1mdv2008.0
+ Revision: 50480
- new version

* Mon Apr 30 2007 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 0.0.9-1mdv2008.0
+ Revision: 19638
- Updated to 0.0.9.


* Fri Mar 23 2007 Götz Waschk <waschk@mandriva.org> 0.0.8-1mdv2007.1
+ Revision: 148576
- Import vala

* Fri Mar 23 2007 Götz Waschk <waschk@mandriva.org> 0.0.8-1mdv2007.1
- initial package

